@@ -10,7 +10,7 @@
 #ifdef BOBCAT
     #include <bobcat/arg>
 #else
-    #include "arg"
+    #include "../arg"
 #endif
 
 using namespace std;
