@@ -5,7 +5,5 @@ Arg &Arg::initialize(char const *optstring, int argc, char **argv)
     if (s_arg)
         throw Exception{} << s_alreadyInitialized;
 
-    s_arg.reset(new Arg(0, optstring, 0, 0, argc, argv));
-
-    return *s_arg;
+    return init(0, optstring, 0, 0, argc, argv);
 }
