@@ -1,6 +1,6 @@
 #include "argconfig.ih"
 
-unique_ptr<ArgConfig> ArgConfig::s_argConfig;
+ArgConfig *ArgConfig::s_argConfig;
 
 char const ArgConfig::s_alreadyInitialized[] =
                         "ArgConfig::initialize(): already initialized";
