@@ -2,6 +2,7 @@
 
 // no accept, no long options, no file
 
+// static
 ArgConfig &ArgConfig::initialize(char const *optstring,
                              int argc, char **argv,
                              Comment cType, SearchCasing sType, Indices iType)
@@ -9,9 +10,8 @@ ArgConfig &ArgConfig::initialize(char const *optstring,
     if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argConfig.reset(new ArgConfig{ 0, optstring, 0, 0, argc, argv,
-                                     cType, sType, iType }
-                     );
-
-    return *s_argConfig;
+    return init(0, optstring, 
+                0, 0, 
+                argc, argv, 
+                cType, sType, iType);
 }
