@@ -11,12 +11,13 @@ ArgConfig &ArgConfig::initialize(char const *optstring,
     if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argConfig.reset(new ArgConfig{ 0, optstring,
-                                     0, 0,
-                                     argc, argv,
-                                     fname,
-                                     cType, sType, iType }
-                     );
-
-    return *s_argConfig;
+    return init(0, optstring,
+                0, 0,
+                argc, argv,
+                fname,
+                cType, sType, iType);
 }
+
+
+
+
