@@ -9,10 +9,8 @@ ArgConfig &ArgConfig::initialize(int accept, char const *optstring,
     if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argConfig.reset(new ArgConfig{ accept, optstring,
-                                     0, 0,
-                                     argc, argv,
-                                     cType, sType, iType }
-                     );
-    return *s_argConfig;
+    return init(accept, optstring,
+                0, 0,
+                argc, argv,
+                cType, sType, iType);
 }
