@@ -1,8 +1,8 @@
 #include "argconfig.ih"
 
 // accept, long options, file,
-// static
 
+// static
 ArgConfig &ArgConfig::initialize(int accept, char const *optstring,
             LongOption const *begin, LongOption const *const end,
             int argc, char **argv,
@@ -12,12 +12,10 @@ ArgConfig &ArgConfig::initialize(int accept, char const *optstring,
     if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argConfig.reset(new ArgConfig{ accept, optstring,
-                                     begin, end,
-                                     argc, argv,
-                                     fname,
-                                     cType, sType, iType }
-                     );
-
-    return *s_argConfig;
+    return init(accept, optstring,
+                begin, end,
+                argc, argv,
+                fname,
+                cType, sType, iType);
 }
+
