@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::expModc(BigInt const &exponent, BigInt const &mod) const
+BigInt BigInt::expModc(BigInt const &exponent, BigInt const &mod) const
 {
     BigInt ret(*this);
     ret.expMod(exponent, mod);
