@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::setNegativec(bool negative) const
+BigInt BigInt::setNegativec(bool negative) const
 {
     BigInt ret(*this);
     ret.setNegative(negative);
