@@ -1,4 +1,4 @@
 inline size_t BigInt::size() const
 {
-    return BN_num_bits(&d_bn);
+    return BN_num_bits(d_bn);
 }
