@@ -1,8 +1,8 @@
 #include <iostream>
 #include <utility>
 
-#include "../../typetrait/typetrait"
-#include "../binops"
+#include <bobcat//typetrait>
+#include <bobcat/binops>
 
 class Demo
 {
