@@ -1,4 +1,4 @@
-inline bool CmdFinderBase::matchInsensitive(string const &key) const
+inline bool FBB::CmdFinderBase::matchInsensitive(std::string const &key) const
 {
     return
         String::casecmp(d_cmd, key) == 0
