@@ -1,5 +1,5 @@
     // time provides UTC time, zone at zoneMinutes, no DST.
-inline DateTime::DateTime(time_t time, std::chrono::minutes zoneMinutes)
+inline FBB::DateTime::DateTime(time_t time, std::chrono::minutes zoneMinutes)
 :
     DateTime(time, Zone{ seconds2str(zoneMinutes.count() * 60) } ) // -> 8.cc
 {}
