@@ -1,6 +1,6 @@
 #include <iostream>
 
-#include "../datetime"
+#include <bobcat/datetime>
 
 using namespace std;
 using namespace FBB;
