@@ -7,5 +7,5 @@ void Exception::open(StreamType &stream, std::string const &name,
 
     stream.open(name, mode);
     if (!stream)
-        throw Exception() << "Can't open `" << name << '\'';
+        throw Exception{} << "Can't open `" << name << '\'';
 }
