@@ -18,7 +18,7 @@ try
                      argc == 3 ? 1024 : stoul(argv[3]) };
 
     HMacBuf empty;                              // Demo: an empty HMacBuf
-    empty = HMacBuf{ "key", "sha256", 100 };    // Demo: move assignmeent
+    empty = HMacBuf{ argv[1], "sha256", 100 };  // Demo: move assignmeent
 
     ostream out(&hmacbuf);              // the ostream receiving the
                                         // input to compute the hmac of
