@@ -1,15 +1,17 @@
 #include "hmacbuf.ih"
 
+// override
 int HMacBuf::overflow(int ch)
 {
-    HMAC_Update(d_ctx, ucharPtr(), bufSize());
+    EVP_MAC_update(d_ctx, ucharPtr(), bufSize());
 
-    setp();
+    setp();                             // FBB::EoiBuf
 
     if (ch != EOF)
     {
         *pptr() = ch;
         pbump(1);
     }
+
     return ch;
 }
