@@ -1,7 +1,7 @@
-#include "../ibase64stream"
-
 #include <iostream>
 
+#include <bobcat/ibase64stream>
+
 using namespace std;
 using namespace FBB;
 
