@@ -1,4 +1,4 @@
 inline std::ostream &nlindent(std::ostream &out)
 {
-    return out << "\n" << indent;
+    return out << '\n' << indent;
 }
