@@ -12,7 +12,9 @@
 // static
 void MemoryAccess::drop(MemoryAccess *ptr, bool erase)
 {
-    ptr->disconnect(s_loaded[ptr->d_idx]);  // disconnect an activated block
+    if (not s_loaded.empty())               // disconnect an activated block
+        ptr->disconnect(s_loaded[ptr->d_idx]);  
+
 
     if (erase)
     {
