@@ -1,7 +1,7 @@
 #define XERR "memoryaccess"
 #include "memoryaccess.ih"
 
-    // by memorybridge/memorybridge3.cc
+    // by memorybridge/memorybridge4.cc
 
 // static
 MemoryAccess *MemoryAccess::loadID(int id)
@@ -11,8 +11,8 @@ MemoryAccess *MemoryAccess::loadID(int id)
     if (ptr == 0)
         throw Exception{} << "No MemoryAccess " << id;
 
-    MemoryAccess *ma = static_cast<MemoryAccess *>(ptr);
-    ma->info(cerr);
+    // MemoryAccess *ma = static_cast<MemoryAccess *>(ptr);
+    // ma->info(cerr);
     
     return static_cast<MemoryAccess *>(ptr);
 }
