@@ -3,7 +3,7 @@
 #include <ostream>
 #include <string>
 
-#include "../ofdbuf"
+#include <bobcat/ofdbuf>
 
 using namespace std;
 using namespace FBB;
