@@ -1,5 +1,5 @@
 inline OFdStream::OFdStream(int fd, size_t n)
 :
-    OFdStreambuf(fd, n),
+    OFdBuf(fd, n),
     std::ostream(this)
 {}
