@@ -1,4 +1,4 @@
-inline lm::lm(int value)
+inline FBB::lm::lm(int value)
 :
     d_value(value < 0 ? 0 : value)
 {}
