@@ -1,4 +1,4 @@
-inline void OFoldBuf::setTrailingBlanks(TrailingBlanks tb)
+inline void FBB::OFoldBuf::setTrailingBlanks(TrailingBlanks tb)
 {
     d_handleTrailingBlanks =  tb ==  HANDLE_TRAILING_BLANKS;
 }
