@@ -1,4 +1,4 @@
-inline void OFoldBuf::useTabs(size_t tabWidth)
+inline void FBB::OFoldBuf::useTabs(size_t tabWidth)
 {
     d_indentChar = '\t';
     d_indentWidth = tabWidth;
