@@ -1,4 +1,4 @@
-inline void OFoldBuf::writeWs() const
+inline void FBB::OFoldBuf::writeWs() const
 {
     out().write(d_ws.data(), d_ws.length());
 }
