@@ -2,10 +2,10 @@
 
 ReadLineBuf &ReadLineBuf::initialize(std::string const &prompt, Type type)
 {
-    if (s_readLineBuf.get() != 0)
+    if (s_readLineBuf != 0)
         throw logic_error("ReadLineBuf already initialized");
 
-    s_readLineBuf.reset(new ReadLineBuf(prompt, type));
-
-    return *s_readLineBuf;
+    static ReadLineBuf buf{ prompt, type };
+    s_readLineBuf = &buf;
+    return buf;
 }
