@@ -6,7 +6,7 @@ ReadLineBuf &ReadLineBuf::initialize(std::string const &prompt,
     if (s_readLineBuf != 0)
         throw logic_error("ReadLineBuf already initialized");
 
-    s_readLineBuf.reset(new ReadLineBuf(prompt, historySize, type));
-
-    return *s_readLineBuf;
+    static ReadLineBuf buf{ prompt, historySize, type };
+    s_readLineBuf = &buf;
+    return buf;
 }
