@@ -2,7 +2,12 @@
 
 ReadLineHistory &ReadLineHistory::instance(bool useTimestamps)
 {
-    s_readLineHistory.reset(new ReadLineHistory);
+    if (s_readLineHistory == 0)
+    {
+        static ReadLineHistory history;
+        s_readLineHistory = &history;
+    }
+
     s_readLineHistory->setTimestampsIO(useTimestamps);
 
     return *s_readLineHistory;
