@@ -3,5 +3,5 @@
 ReadLineHistory::HistoryElement const
     &ReadLineHistory::const_iterator::operator*() const
 {
-    return d_element.set(history_list()[d_idx]);
+    return d_elements[d_idx];
 }
