@@ -2,7 +2,7 @@
 #include <iterator>
 #include <algorithm>
 
-#include "../repeat"
+#include <bobcat/repeat>
 
 using namespace std;
 using namespace FBB;
@@ -53,6 +53,3 @@ int main(int argc, char **argv)
     repeat(argc, obj, &Object::member, argc, argv);
 
 }
-
-
-
