@@ -1,11 +1,15 @@
 #include "signal.ih"
 
-unique_ptr<Signal> Signal::s_signal;
+Signal *Signal::s_signal;
 
 Signal &Signal::instance()
 {
+
     if (s_signal == 0)
-        s_signal.reset(new Signal);
+    {
+        static Signal signal;
+        s_signal = &signal;
+    }
 
     return *s_signal;
 }
