@@ -1,12 +1,8 @@
-/*
-                              driver.cc
-*/
-
 #include <iostream>
 #include <string>
 
-#include "../stat"
 #include <bobcat/datetime>
+#include <bobcat/stat>
 
 using namespace std;
 using namespace FBB;
@@ -50,9 +46,8 @@ int main(int argc, char **argv)
 
     cout << st.name() << ": access: " << st.lastAccess() << "\n" <<
             st.name() << ": change: " << st.lastChange() << "\n" <<
-            st.name() << ": modif:  " << st.lastModification() << "\n"   
-            "Mode: " << oct << st.mode() <<  " (" << st.modeStr() << ")\n" 
+            st.name() << ": modif:  " << st.lastModification() << "\n"
+            "Mode: " << oct << st.mode() <<  " (" << st.modeStr() << ")\n"
             "Type: " << st.type() << " (" << st.typeStr() << ")\n"
             "Full path:  " << st.path()  << endl;
 }
-
