@@ -1,6 +1,6 @@
 #include "syslogbuf.ih"
 
-Priority Syslogbuf::setPriority(Priority priority)
+Priority SyslogBuf::setPriority(Priority priority)
 {
     Priority old = d_priority;
     d_priority = priority;
