@@ -1,4 +1,4 @@
 inline Priority SyslogStream::defaultPriority()   const
 {
-    return Syslogbuf::defaultPriority();
+    return SyslogBuf::defaultPriority();
 }
