@@ -1,4 +1,4 @@
-inline void TableBase::clear()
+inline void FBB::TableBase::clear()
 {
     d_tabulated = false;
     d_string.clear();
