@@ -1,5 +1,7 @@
 #include "tablebase.ih"
 
+std::ios_base &(*ctr)(std::ios_base &stream) = FBB::center;
+
 ostream &TableBase::insert(ostream &ostr)
 {
     def();
@@ -24,7 +26,8 @@ ostream &TableBase::insert(ostream &ostr)
             if (!manip)
                 manip = columnManip(col);
 
-            if (manip != FBB::center)
+            // if (manip != FBB::center)
+            if (manip != ctr)
                 ostr << manip << setw(colwidth) << element.d_text;
             else
             {
