@@ -1,4 +1,4 @@
-inline void TableSupport::leftType(size_t *target, size_t type)
+inline void FBB::TableSupport::leftType(size_t *target, size_t type)
 {
     *target =   *target != SKIP || (type & (USE | LEFT_FULL)) ?
                     USE
