@@ -1,9 +1,13 @@
 #include "tablesupport.ih"
 
-TableSupport &FBB::operator<<(TableSupport &support, size_t width)
+namespace FBB
+{
+
+TableSupport &operator<<(TableSupport &support, size_t width)
 {
     support.d_sep.push_back(std::string(width, ' '));
     --support.d_tableWidth;
     return support;
 }
 
+}
