@@ -1,9 +1,13 @@
 #include "tablesupport.ih"
 
-TableSupport &FBB::operator<<(TableSupport &support, std::string const &sep)
+namespace FBB
+{
+
+TableSupport &operator<<(TableSupport &support, std::string const &sep)
 {
     support.d_sep.push_back(sep);
     --support.d_tableWidth;
     return support;
 }
 
+}
