@@ -2,5 +2,5 @@
 
 TempStream::~TempStream()
 {
-    unlink(d_fileName.c_str());
+    unlink(d_filename.c_str());
 }
